@@ -10,18 +10,23 @@ AUTHOR:		smartfish kafa
  This file may be used, distributed and modified without limitation.
  *******************************************************************************/
 
+
 #ifndef GLOBAL_H
 #define GLOBAL_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#else 
+#define VERSION	"0.4.1"
+#define QTERM_DATADIR "/usr/share/qterm"
+#define QTERM_BINDIR  "/usr/bin"
+#endif
 
 #ifndef BUFSIZE
 #define BUFSIZE (1024)
 #endif
 
-//assume the sreen is 80*24
-#define CHARNUM 80
-#define LINENUM 24
-
+#include <qtextcodec.h>
 //code convert
 #define G2U(s) ( QTextCodec::codecForName("GBK")->toUnicode(s) )
 #define U2G(s) ( QTextCodec::codecForName("GBK")->fromUnicode(s) )
@@ -117,6 +122,12 @@ AUTHOR:		smartfish kafa
 #define NULL 0
 #endif
 
+#define DAE_FINISH  10001
+#define DAE_TIMEOUT 10002
+
+#define PYE_ERROR   10003
+#define PYE_FINISH  10004
+
 // some keys
 #define CHAR_CR 	0x0d	// ^M
 #define CHAR_LF		0x0a	// ^J
@@ -128,6 +139,7 @@ AUTHOR:		smartfish kafa
 
 #define CHAR_NORMAL	-1
 
+// telnet state
 #define TSRESOLVING		30
 #define TSHOSTFOUND		31
 #define TSHOSTNOTFOUND	32
@@ -145,7 +157,9 @@ AUTHOR:		smartfish kafa
 #define TSEINIWINSOCK	45
 #define TSERROR			46
 #define TSPROXYERROR	47
+#define	TSWRITED		48
 
+// proxy type
 #define NOPROXY			0
 #define WINGATE			1
 #define SOCKS4			2
