@@ -74,6 +74,9 @@ QTermScreen::QTermScreen( QWidget *parent, QTermBuffer *buffer, QTermParam *para
 	m_cursorTimer = new QTimer(this);
 	connect(m_cursorTimer, SIGNAL(timeout()), this, SLOT(cursorEvent()));
 
+	m_resizeTimer = new QTimer(this);
+	connect(m_resizeTimer, SIGNAL(timeout()), this, SLOT(resizeWindow()));
+
 	m_inputContent = NULL;
 
 	// the scrollbar
@@ -110,6 +113,9 @@ QTermScreen::QTermScreen( QWidget *parent, QTermBuffer *buffer, QTermParam *para
 		m_pCodec = QTextCodec::codecForName("GBK");
 	else
 		m_pCodec = QTextCodec::codecForName("Big5");
+	m_pxmBuffer = new QPixmap(this->size());
+	m_pxmBuffer->fill(m_color[0]);
+	resizeWindow();
 }
 
 QTermScreen::~QTermScreen()
@@ -208,7 +214,8 @@ void QTermScreen::moveEvent( QMoveEvent * )
 {
 //	setBgPxm( m_pxmBg, m_nPxmType );
 }
-void QTermScreen::resizeEvent( QResizeEvent *  )
+
+void QTermScreen::resizeWindow()
 {
 	updateScrollBar();
 	setBgPxm( m_pxmBg, m_nPxmType );
@@ -226,6 +233,15 @@ void QTermScreen::resizeEvent( QResizeEvent *  )
 			m_pBuffer->setSize( cx, cy );
 		}
 	}
+	delete m_pxmBuffer;
+	m_pxmBuffer = new QPixmap(this->size());
+	m_pxmBuffer->fill(m_color[0]);
+	update();
+}
+
+void QTermScreen::resizeEvent( QResizeEvent *  )
+{
+	m_resizeTimer->start(50,true);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -718,7 +734,7 @@ void QTermScreen::setBgPxm( const QPixmap& pixmap, int nType)
 void QTermScreen::blinkScreen()
 {
 	QPainter painter;
-	painter.begin(this);
+	painter.begin(m_pxmBuffer);
 	int startx;
 	for (int index=m_nStart; index<=m_nEnd; index++)
 		if (m_pBlinkLine[index - m_nStart]) {
@@ -735,6 +751,8 @@ void QTermScreen::blinkScreen()
 					drawLine(painter, index, startx, i, false);
 				}
 		}
+	painter.end();
+	bitBlt(this, 0, 0, m_pxmBuffer, 0, 0, m_pxmBuffer->width(), m_pxmBuffer->height(), Qt::CopyROP);
 }
 
 // refresh the screen when 
@@ -753,9 +771,7 @@ void QTermScreen::refreshScreen( )
 	int startx, endx;
 
 	QPainter painter;
-	painter.begin(this);
-	
-	
+	painter.begin(m_pxmBuffer);
 	for(int index=m_nStart; index<=m_nEnd; index++ )
 	{
 		if ( index>=m_pBuffer->lines() )
@@ -782,14 +798,15 @@ void QTermScreen::refreshScreen( )
 */
 		startx = testChar(startx, index);
 
-		erase(mapToRect(startx, index, -1, 1));
-
+		painter.fillRect(mapToRect(startx, index, -1, 1), m_color[0]);
 		drawLine( painter, index, startx);
 
 		pTextLine->clearChange();
 	}
 	painter.end();
 
+	bitBlt(this, 0, 0, m_pxmBuffer, 0, 0, m_pxmBuffer->width(), m_pxmBuffer->height(), Qt::CopyROP);
+
 	setUpdatesEnabled(TRUE);
 
 	setMicroFocusHint((m_pBuffer->caret().x()+2)*m_nCharWidth,(m_pBuffer->caret().y()+1)*m_nCharHeight, 
@@ -855,12 +872,16 @@ int QTermScreen::testChar(int startx, int index)
 		
 void QTermScreen::paintEvent( QPaintEvent * pe )
 {
-	
+	if (m_resizeTimer->isActive()){
+		bitBlt(this, 0, 0, m_pxmBuffer, 0, 0, m_pxmBuffer->width(), m_pxmBuffer->height(), Qt::CopyROP);
+		return;
+	}
+
 	QPainter painter;
 
 	setUpdatesEnabled( false );
 	
-	painter.begin( this );
+	painter.begin( m_pxmBuffer );
 	
 	QRect rect = pe->rect().intersect(m_rcClient);
 
@@ -870,7 +891,16 @@ void QTermScreen::paintEvent( QPaintEvent * pe )
 
 	for( int y=tlPoint.y(); y<=brPoint.y(); y++ )
 	{
+		painter.fillRect(mapToRect(0, y, -1, 1), m_color[0]);
 		drawLine(painter,y);
+	}
+
+	painter.end();
+
+	bitBlt(this, 0, 0, m_pxmBuffer, 0, 0, m_pxmBuffer->width(), m_pxmBuffer->height(), Qt::CopyROP);
+
+	for( int y=tlPoint.y(); y<=brPoint.y(); y++ )
+	{
 		if( m_pBBS->isSelected(y)&&m_pParam->m_nMenuType==1 )
 		{
 			QRect rcMenu = mapToRect(m_pBBS->getSelectRect());
@@ -879,8 +909,6 @@ void QTermScreen::paintEvent( QPaintEvent * pe )
 					rcMenu.width(), rcMenu.height(), Qt::NotROP );
 		}
 	}
-	
-	painter.end();
 
 	setUpdatesEnabled( true );
 
@@ -920,7 +948,6 @@ void QTermScreen::drawLine( QPainter& painter, int index, int starx, int endx, b
 			starx = 0;
 			endx = linelength;
 		}
-
 	for( uint i=starx; i < endx;i++)
 	{
 		int offset = 0;
@@ -1044,12 +1071,7 @@ void QTermScreen::drawStr( QPainter& painter, const QString& str, int x, int y,
 
 
 	if( m_blinkScreen && GETBLINK(GETATTR(attribute)))
-	{
-		if(GETBG(cp)!=0)
-			painter.fillRect( mapToRect(x,y,length,1), QBrush(m_color[GETBG(cp)]) );
-		else
-			erase( mapToRect(x, y, length, 1) );
-	}
+		painter.fillRect( mapToRect(x,y,length,1), QBrush(m_color[GETBG(cp)]) );
 	else {
 		if(GETBG(cp)!=0)
 			painter.fillRect( mapToRect(x,y,length,1), QBrush(m_color[GETBG(cp)]) );
@@ -1363,4 +1385,6 @@ void QTermInput::paintEvent(QPaintEvent * e)
 #endif
 	inputPainter.end();
 }
-#include <qtermscreen.moc>
+#ifdef HAVE_CONFIG_H
+#include "qtermscreen.moc"
+#endif
