@@ -579,4 +579,12 @@ Q_ULONG QTermTelnetSocket::bytesAvailable()
 {
 	return d_socket->bytesAvailable();
 }
-#include <qtermsocket.moc>
+
+bool QTermTelnetSocket::allowInput()
+{
+	return true;
+}
+
+#ifdef HAVE_CONFIG_H
+#include "qtermsocket.moc"
+#endif
