@@ -462,6 +462,9 @@ int QTermTelnet::read(char * data, uint maxlen)
  */
 int QTermTelnet::write(const char * data, uint len)
 {
+	if (!socket->allowInput())
+		return 0;
+
 	// accept data, (This seems can be removed????)
 	from_ansi->resize(len);
 	memcpy(from_ansi->data(), data, len);
@@ -914,5 +917,6 @@ int QTermTelnet::tnabort(int)
 //	exit(-1);
 	return -1;
 }
-
-#include <qtermtelnet.moc>
+#ifdef HAVE_CONFIG_H
+#include "qtermtelnet.moc"
+#endif
