@@ -1,22 +1,8 @@
 #ifndef QTERMTELNET_H
 #define QTERMTELNET_H
 
-// _OS_WIN32_ not defined if i dont include it
-#include <qglobal.h>
-// different 
-#ifdef _OS_WIN32_
-	#include <winsock2.h>
-#else
-	#include <netdb.h>
-	#include <sys/socket.h>
-	#include <sys/types.h>
-	#include <arpa/inet.h>
-#endif
-
 #include <qobject.h>
 
-class QSocket;
-
 #ifndef u_char
 #define u_char uchar
 #endif
@@ -79,11 +65,10 @@ class QSocket;
 
 
 // Telnet Option Subnegotiation FSM States:
-#define SS_START	0		// initial state			
-#define	SS_TERMTYPE	1		// TERMINAL_TYPE option subnegotiation	
-#define	SS_END		2		// state after all legal input		
-
-#define	NSSTATES	3		// # of SS_* states			
+#define SS_START	0		// initial state
+#define	SS_TERMTYPE	1		// TERMINAL_TYPE option subnegotiation
+#define	SS_END		2		// state after all legal input
+#define	NSSTATES	3		// # of SS_* states	
 
 #define	FSINVALID	0xff		// an invalid state number		
 #define	NCHRS		256		// number of valid characters	
@@ -112,18 +97,16 @@ struct fsm_trans {
 *-------------------------------------------------------------------------------
 */
 
-class QSocket;
+class QTermSocket;
 
 class QTermTelnet : public QObject
 {
     Q_OBJECT
 
 public:
-	QTermTelnet( const QCString ) ;
+	QTermTelnet( const QCString termtype, int rows, int columns, bool isSSH, const char * sshuser = NULL, const char * sshpasswd = NULL ) ;
 	~QTermTelnet();
 	
-	void setWindowSize( int x, int y );
-
 	void setProxy( int nProxyType,//0-no proxy; 1-wingate; 2-sock4; 3-socks5
 		bool bAuth,	// if authentation needed
 		const QString& strProxyHost,Q_UINT16 uProxyPort,
@@ -132,6 +115,12 @@ public:
 	int  read(char * data, uint maxlen);
 	int  write(const char * data, uint len);
 	void close();				// User close the connection
+	
+	int raw_len();
+	int read_raw(char *data, uint maxlen);
+
+public slots:
+	void windowSizeChanged(int, int);
 
 signals:
 	void readyRead(int);		// There are datas to be read out
@@ -148,7 +137,7 @@ protected:
 	void init_telnet();
 	void fsmbuild();
 	void fsminit(u_char fsm[][NCHRS], struct fsm_trans ttab[], int nstates);
-	
+
 	//actions
 	int tcdm(int);
 	int recopt(int);
@@ -173,10 +162,6 @@ protected:
 	int xputs_up(char *);
 	void putc_down(u_char);	
 
-	// socks5 function
-	void socks5_connect();
-	void socks5_auth();
-	void socks5_reply( int );
 	
 private:
 	// Boolean Flags
@@ -197,9 +182,7 @@ private:
 	static const  char	sg_erase=CTRL('?');		// Erase a character 	i.e:(^?)
 	static const  char	sg_kill=CTRL('U');		// Kill a line 		i.e:(^U)
         */
-	
-	static const  char	wingate_enter;			// Wingate accept ^J as enter
-	
+		
 	// FSM stuffs	
 	static struct fsm_trans ttstab[];
 	int	ttstate;
@@ -210,7 +193,7 @@ private:
 	u_char	subfsm[NSSTATES][NCHRS];
 
 	// socket stuffs
-	QSocket *socket;
+	QTermSocket *socket;
 	
 	//Pointers to internal buffers
 	//
@@ -222,21 +205,13 @@ private:
 	uint rsize;	// size of to_ansi buffer
 	uint wsize;	// size of to_socket buffer
 	
-	// proxy 
-	int 		proxy_type;
-	QString 	proxy_host;
-	QString 	proxy_usr;
-	Q_UINT16  	proxy_port;
-	QString 	proxy_pwd;
-	QString 	host;
-	Q_UINT16 	port;
-	int		proxy_state;
-	bool		bauth;
-	struct sockaddr_in  addr_host;
 
 	// for test
 	int wx, wy;
 	int done_naws;
+	bool d_isSSH;
+	bool bConnected;
+	int raw_size;
 };
 
 #endif	// QTERMTELNET_H
