@@ -854,5 +854,6 @@ QImage& schemaDialog::fadeColor( QImage& img, float val, const QColor& color)
 
     return img;
 }
-
-#include <schemadialog.moc>
+#ifdef HAVE_CONFIG_H
+#include "schemadialog.moc"
+#endif
